======================
Command line reference
======================

`tarbell configure`
-------------------


`tarbell newproject`
--------------------

`tarbell serve`
---------------

**Requires current directory to be a Tarbell project.**

`tarbell publish`
-----------------

**Requires current directory to be a Tarbell project.**

`tarbell unpublish`
-------------------

**Requires current directory to be a Tarbell project.**

`tarbell update`
----------------

**Requires current directory to be a Tarbell project.**

`tarbell generate`
------------------

**Requires current directory to be a Tarbell project.**

`tarbell switch`
----------------

`tarbell list`
--------------

`tarbell install`
-----------------

`tarbell install-template`
--------------------------



